From 580b5a936bd91f5daf00b20ae41b551ee3465ed2 Mon Sep 17 00:00:00 2001
From: Greg Hogan <code@greghogan.com>
Date: Fri, 30 Apr 2021 13:59:30 +0000
Subject: [PATCH 05/10] gnu: Add aws-c-compression.

* gnu/packages/c.scm (aws-c-compression): New variable.
* gnu/packages/patches/aws-c-compression-cmake-prefix.patch: New file.
* gnu/local.mk (dist_patch_DATA): Add it.
---
 gnu/local.mk                                  |  1 +
 gnu/packages/c.scm                            | 27 +++++++++++++++++++
 .../aws-c-compression-cmake-prefix.patch      | 13 +++++++++
 3 files changed, 41 insertions(+)
 create mode 100644 gnu/packages/patches/aws-c-compression-cmake-prefix.patch

diff --git a/gnu/local.mk b/gnu/local.mk
index 5b38a26391..37573b5b7a 100644
--- a/gnu/local.mk
+++ b/gnu/local.mk
@@ -836,6 +836,7 @@ dist_patch_DATA =						\
   %D%/packages/patches/avidemux-install-to-lib.patch		\
   %D%/packages/patches/awesome-reproducible-png.patch		\
   %D%/packages/patches/aws-c-cal-cmake-prefix.patch		\
+  %D%/packages/patches/aws-c-compression-cmake-prefix.patch	\
   %D%/packages/patches/aws-c-event-stream-cmake-prefix.patch  \
   %D%/packages/patches/aws-c-http-cmake-prefix.patch		\
   %D%/packages/patches/aws-c-http-disable-networking-tests.patch\
diff --git a/gnu/packages/c.scm b/gnu/packages/c.scm
index f9037db005..08ce250333 100644
--- a/gnu/packages/c.scm
+++ b/gnu/packages/c.scm
@@ -726,3 +726,30 @@ cryptographic primitives for the @acronym{AWS,Amazon Web Services} SDK.")
 specifications.")
     (home-page "https://github.com/awslabs/aws-c-http")
     (license license:asl2.0)))
+
+(define-public aws-c-compression
+  (package
+    (name "aws-c-compression")
+    (version "0.2.10")
+    (source (origin
+              (method git-fetch)
+              (uri (git-reference
+                    (url (string-append "https://github.com/awslabs/" name))
+                    (commit (string-append "v" version))))
+              (file-name (git-file-name name version))
+              (sha256
+               (base32
+                "01l4z7i07qhrw0dqsr0wvdwrn4bd494a1klxsyjvq0dah6iswvlv"))
+              (patches (search-patches "aws-c-compression-cmake-prefix.patch"))))
+    (build-system cmake-build-system)
+    (arguments
+     '(#:configure-flags
+       '("-DBUILD_SHARED_LIBS=ON")))
+    (propagated-inputs
+     `(("aws-c-common" ,aws-c-common)))
+    (synopsis "Amazon Web Services compression library")
+    (description
+     "This library provides a C99 implementation of compression algorithms,
+currently limited to Huffman encoding and decoding.")
+    (home-page "https://github.com/awslabs/aws-c-compression")
+    (license license:asl2.0)))
diff --git a/gnu/packages/patches/aws-c-compression-cmake-prefix.patch b/gnu/packages/patches/aws-c-compression-cmake-prefix.patch
new file mode 100644
index 0000000000..eefae19c4a
--- /dev/null
+++ b/gnu/packages/patches/aws-c-compression-cmake-prefix.patch
@@ -0,0 +1,13 @@
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -5,6 +5,10 @@ if (POLICY CMP0069)
+     cmake_policy(SET CMP0069 NEW) # Enable LTO/IPO if available in the compiler, see AwsCFlags
+ endif()
+ 
++if (DEFINED ENV{CMAKE_PREFIX_PATH})
++    set(CMAKE_PREFIX_PATH $ENV{CMAKE_PREFIX_PATH})
++endif()
++
+ if (DEFINED CMAKE_PREFIX_PATH)
+     file(TO_CMAKE_PATH "${CMAKE_PREFIX_PATH}" CMAKE_PREFIX_PATH)
+ endif()
-- 
2.31.1

